@@ -6,7 +6,7 @@ use Benchmark qw(cmpthese timethese);
 use File::Basename;
 
 use PerlIO::Util;
-my $perlbin = dirname $^X;
+my $perlbin = -d '/usr/bin' ? '/usr/bin' : dirname $^X;
 
 my $count = do{
 	my $n = 0;
