@@ -5,12 +5,11 @@ use warnings;
 use Benchmark qw(cmpthese timethese);
 
 use PerlIO::Util;
-my $file = @ARGV ? shift(@ARGV) : `perldoc -l perl`;
-
-$file =~ s/\s+$//;
+my $file = `perldoc -l perl`;
+chomp $file;
 
 {
-	my $in = PerlIO::Util->open('<', $file);
+	my $in = PerlIO::Util->open('<:perlio', $file);
 	local $/;
 	my $content = <$in>;
 
@@ -21,7 +20,7 @@ $file =~ s/\s+$//;
 
 cmpthese timethese -1 => {
 	':reverse' => sub{
-		open my $in, '<:reverse', $file or die $!;
+		open my $in, '<:unix:reverse', $file or die $!;
 		while(<$in>){
 			#...;
 		}
